@@ -133,7 +133,7 @@ class RouteResponse(Response):
                 sl = lfb.StepsLength()
                 for s in range(0, sl):
                     sfb = lfb.Steps(s)
-                    step = Step(geometry = sfb.Geometry())
+                    step = Step(geometry=sfb.Geometry())
                     leg.steps.append(step)
                 route.legs.append(leg)
             routes.append(route)
@@ -143,6 +143,8 @@ class RouteResponse(Response):
 class POI(BaseModel):
     name: str
     location: LngLat
+    hint: str
+    distance: float
 
 
 class TableResponse(Response):
@@ -283,7 +285,10 @@ class API:
         url += "?" + urlencode(params)
         return await self._call(url, output_format, MatchResponse)
 
-    async def route(self, coords: List[LatLng], output_format: OutputFormat, geometry: Geometry = Geometry.polyline, steps: bool = False) -> RouteResponse:
+    async def route(self, coords: List[LatLng], output_format: OutputFormat, geometry: Geometry = Geometry.polyline, steps: bool = False, alternatives: bool = False, altcount: int = 3) -> RouteResponse:
         coords_param = ';'.join([f'{c.lng},{c.lat}' for c in coords])
-        url = f'{self.base_url}/route/v1/driving/{coords_param}.{output_format}?overview=full&geometries={geometry}&steps={steps}'
+        altparam = ''
+        if alternatives:
+            altparam = f'&alternatives={altcount}'
+        url = f'{self.base_url}/route/v1/driving/{coords_param}.{output_format}?overview=full&geometries={geometry}&steps={str(steps).lower()}{altparam}'
         return await self._call(url, output_format, RouteResponse)
