@@ -45,9 +45,25 @@ def test_route_response():
                     {
                         'distance': 1.0,
                         'duration': 1.0,
-                        'steps':[
+                        'steps': [
                             {
-                                'geometry':'whocares2',
+                                'geometry': 'whocares2',
+                            }
+                        ],
+                    },
+                ],
+            },
+            {
+                'geometry': 'whocares',
+                'distance': 2.0,
+                'duration': 2.0,
+                'legs': [
+                    {
+                        'distance': 2.0,
+                        'duration': 2.0,
+                        'steps': [
+                            {
+                                'geometry': 'whocares2',
                             }
                         ],
                     },
@@ -58,6 +74,8 @@ def test_route_response():
     r = RouteResponse(**mock)
     assert r.routes[0].geometry == 'whocares'
     assert r.routes[0].legs[0].steps[0].geometry == 'whocares2'
+    assert r.routes[1].geometry == 'whocares'
+    assert r.routes[1].legs[0].steps[0].geometry == 'whocares2'
 
 
 def test_table_response():
@@ -67,12 +85,16 @@ def test_table_response():
             {
                 'name': 'whocares',
                 'location': [1.0, 2.0],
+                'hint': '',
+                'distance': 0.1,
             },
         ],
         'destinations': [
             {
                 'name': 'whocares',
                 'location': [1.0, 2.0],
+                'hint': '',
+                'distance': 0.1,
             },
         ],
         'durations': [
